print("import: 'PySide2.QtCharts'")
import PySide2.QtCharts

print("import: 'PySide2.QtConcurrent'")
import PySide2.QtConcurrent

print("import: 'PySide2.QtCore'")
import PySide2.QtCore

print("import: 'PySide2.QtDataVisualization'")
import PySide2.QtDataVisualization

print("import: 'PySide2.QtGui'")
import PySide2.QtGui

print("import: 'PySide2.QtHelp'")
import PySide2.QtHelp

print("import: 'PySide2.QtLocation'")
import PySide2.QtLocation

print("import: 'PySide2.QtMultimedia'")
import PySide2.QtMultimedia

print("import: 'PySide2.QtMultimediaWidgets'")
import PySide2.QtMultimediaWidgets

print("import: 'PySide2.QtNetwork'")
import PySide2.QtNetwork

print("import: 'PySide2.QtOpenGL'")
import PySide2.QtOpenGL

print("import: 'PySide2.QtPositioning'")
import PySide2.QtPositioning

print("import: 'PySide2.QtPrintSupport'")
import PySide2.QtPrintSupport

print("import: 'PySide2.QtQml'")
import PySide2.QtQml

print("import: 'PySide2.QtQuick'")
import PySide2.QtQuick

print("import: 'PySide2.QtQuickWidgets'")
import PySide2.QtQuickWidgets

print("import: 'PySide2.QtRemoteObjects'")
import PySide2.QtRemoteObjects

print("import: 'PySide2.QtScript'")
import PySide2.QtScript

print("import: 'PySide2.QtScriptTools'")
import PySide2.QtScriptTools

print("import: 'PySide2.QtScxml'")
import PySide2.QtScxml

print("import: 'PySide2.QtSensors'")
import PySide2.QtSensors

print("import: 'PySide2.QtSql'")
import PySide2.QtSql

print("import: 'PySide2.QtSvg'")
import PySide2.QtSvg

print("import: 'PySide2.QtTest'")
import PySide2.QtTest

print("import: 'PySide2.QtTextToSpeech'")
import PySide2.QtTextToSpeech

print("import: 'PySide2.QtUiTools'")
import PySide2.QtUiTools

print("import: 'PySide2.QtWebChannel'")
import PySide2.QtWebChannel

print("import: 'PySide2.QtWebEngineCore'")
import PySide2.QtWebEngineCore

print("import: 'PySide2.QtWebEngineWidgets'")
import PySide2.QtWebEngineWidgets

print("import: 'PySide2.QtWebSockets'")
import PySide2.QtWebSockets

print("import: 'PySide2.QtWidgets'")
import PySide2.QtWidgets

print("import: 'PySide2.QtXml'")
import PySide2.QtXml

print("import: 'PySide2.QtXmlPatterns'")
import PySide2.QtXmlPatterns

print("import: 'PySide2.Qt3DAnimation'")
import PySide2.Qt3DAnimation

print("import: 'PySide2.Qt3DCore'")
import PySide2.Qt3DCore

print("import: 'PySide2.Qt3DExtras'")
import PySide2.Qt3DExtras

print("import: 'PySide2.Qt3DInput'")
import PySide2.Qt3DInput

print("import: 'PySide2.Qt3DLogic'")
import PySide2.Qt3DLogic

print("import: 'PySide2.Qt3DRender'")
import PySide2.Qt3DRender

